@@ -61,16 +61,18 @@ int nsm_is_active;
 
 char *project_file;
 
+int REAL_JACK_PORT_NAME_SIZE; //defined after jack client activated
+
 #undef VERSION
 #define APP_TITLE "JACKPatch"
-#define VERSION "0.2"
+#define VERSION "1.0.0"
 
 struct patch_record {
     struct {
         char *client;
         char *port;
     } src , dst;
-    int active;                                                 /* true if patch has already been activate (by us) */
+    int active;                                                 /* true if patch has already been activated (by us) */
     struct patch_record *next;
 };
 
@@ -139,6 +141,9 @@ void enqueue_known_port ( const char *port )
     enqueue_port( &known_ports, port );
 }
 
+/**
+ * Find a jack port in our own data structure (and not in the jack graph)
+ */
 const char * find_known_port ( const char *port )
 {
     struct port_record *pr;
@@ -150,6 +155,12 @@ const char * find_known_port ( const char *port )
     return NULL;
 }
 
+
+/**
+ * Convert a symbolic string of a jack connection into actual data struct patch_record
+ * Argument example:
+ * "PulseAudio JACK Sink:front-left          |> system:playback_1"
+ */
 int
 process_patch ( const char *patch )
 {
@@ -229,7 +240,7 @@ process_patch ( const char *patch )
 
     pr->active = 0;
 
-    print_patch( pr, 1 );
+    //print_patch( pr, 1 ); //very verbose
 
     return 1;
 }
@@ -253,6 +264,7 @@ clear_all_patches ( )
 int
 read_config ( const char *file )
 {
+    printf( "[jackpatch] Reading connections from file %s \n", file);
     FILE *fp;
     int i = 0;
 
@@ -293,7 +305,7 @@ read_config ( const char *file )
 
         if ( retval == 0 )
         {
-            printf( "[jackpatch]  bad line %i.\n", i );
+            printf( "[jackpatch] bad line %i.\n", i );
             continue;
         }
     }
@@ -305,18 +317,22 @@ read_config ( const char *file )
 
 
 
-/* returns 0 if connection failed, true if succeeded. Already connected
+/** A connection attempt will only be made when a JACK port registers itself and we receive
+ * the jack callback, and once on startup.
+ * There is no periodic check if a previously saved connection is still alive (by design!).
+ *
+ * returns 0 if connection failed, true if succeeded. Already connected
  * is not considered failure */
 void
 connect_path ( struct patch_record *pr )
 {
     int r = 0;
 
-    char srcport[512];
+    char srcport[512]; // This should really be REAL_JACK_PORT_NAME_SIZE, but in the real world not every system and compiler does C99.
     char dstport[512];
 
-    snprintf( srcport, 512, "%s:%s", pr->src.client, pr->src.port );
-    snprintf( dstport, 512, "%s:%s", pr->dst.client, pr->dst.port );
+    snprintf( srcport, REAL_JACK_PORT_NAME_SIZE, "%s:%s", pr->src.client, pr->src.port );
+    snprintf( dstport, REAL_JACK_PORT_NAME_SIZE, "%s:%s", pr->dst.client, pr->dst.port );
 
     if ( pr->active )
     {
@@ -326,17 +342,29 @@ connect_path ( struct patch_record *pr )
 
     if ( ! ( find_known_port( srcport ) && find_known_port( dstport )  ) )
     {
-        /* one of the ports doesn't exist yet... don't attempt
-         * connection, jack will just complain. */
-        printf( "[jackpatch]  Not attempting connection because one of the ports is missing.\n" );
+
+         /*
+         * Since we only connect KNOWN TO US ports a connection will not be made on startup / file load,
+         * even if both jack ports are actually present in JACK.
+         * This is because we have not parsed both ports yet.
+         * The true connection attempt will be made only when the second port of the pair was parsed.
+         *
+         * The log message below is misleading for users, because nothing is wrong, and should only
+         * be used during development.
+         *
+         * We just skip the first attempt, eventhough JACK will not complain and do nothing wrong.
+         *
+         * That also means that we do not detect actually missing ports.
+         */
+        //printf( "[jackpatch] Not attempting connection because one of the ports is missing: %s %s\n", srcport, dstport );
         return;
     }
 
-    printf( "[jackpatch]  Connecting %s |> %s\n", srcport, dstport );
+    // printf( "[jackpatch] Connecting %s |> %s\n", srcport, dstport );
 
     r = jack_connect( client, srcport, dstport );
 
-    print_patch( pr, r );
+    //print_patch( pr, r ); //very verbose
 
     if ( r == 0 || r == EEXIST )
     {
@@ -346,7 +374,7 @@ connect_path ( struct patch_record *pr )
     else
     {
         pr->active = 0;
-        printf( "[jackpatch]  Error is %i\n", r );
+        printf( "[jackpatch] Error is %i\n", r );
         return;
     }
 }
@@ -357,8 +385,8 @@ do_for_matching_patches ( const char *portname, void (*func)( struct patch_recor
 {
     struct patch_record *pr;
 
-    char client[512];
-    char port[512];
+    char client[512]; //Linux jack limit is 64
+    char port[512];  //linux jack limit is 256
 
     sscanf( portname, "%[^:]:%[^\n]", client, port );
 
@@ -416,13 +444,19 @@ void remove_known_port ( const char *port )
     inactivate_patch ( port );
 }
 
-/** called for every new port */
+/**
+ * Called for every new port, which includes restored-from-file ports on startup.
+ * It will try to activate a restored connection for every single port, thus doing an attempt
+ * twice: Once for the source-port and then for the destination-port.
+ */
 void
 handle_new_port ( const char *portname )
 {
     enqueue_known_port( portname );
 
-    printf( "[jackpatch]  New endpoint '%s' registered.\n", portname );
+    //Verbose output that a new port was detected during runtime
+    //printf( "[jackpatch] New endpoint '%s' registered.\n", portname );
+
     /* this is a new port */
     activate_patch( portname );
 }
@@ -449,6 +483,22 @@ static int stringsort ( const void *a, const void *b )
     return strcmp(* (char * const *) a, * (char * const *) b);
 }
 
+/**
+ * Save all current connections to a file.
+ *
+ * Strategy:
+ * If there are no jack ports at all don't do anything. Else:
+ *
+ * Remember all currently known connections where one, or both, ports are missing from the jack graph.
+ * We consider these temporarily gone by accident.
+ *
+ * Clear the current save file.
+ *
+ * For each currently existing jack output port save all of it's connections.
+ * Save all these port-pairs in an empty file. Ports without connections are not saved.
+ **
+ */
+
 void
 snapshot ( const char *file )
 {
@@ -462,19 +512,94 @@ snapshot ( const char *file )
 
     if ( NULL == ( fp = fopen( file, "w" ) ) )
     {
-        fprintf( stderr, "[jackpatch]  Error opening snapshot file for writing" );
+        fprintf( stderr, "[jackpatch] Error opening snapshot file for writing\n" );
         return;
     }
 
-    clear_all_patches();
 
+    //Prepare a temporary table where all connection strings are held until the file is written at the bottom of this function.
+    //We first add all connections that are temporarily out of order (see below) and then all currently existing connections.
     const int table_increment = 16;
     int table_index = 0;
     size_t table_size = table_increment;
     char **table = (char**)malloc( sizeof( char * ) * table_increment );
 
+
+    //Before we forget the current state find all connections that we have in memory but where
+    //one or both ports are currently missing in the jack graph.
+    //We don't want to lose connections that are just temporarily not present.
+    struct patch_record *pr;
+    while ( patch_list )
+    {
+        //A patch is one connection between a source and a destination.
+        //If an actual jack port source is connected to more than one destinations it will appear as it's own "patch" in this list.
+        //We only need to consider 1:1 point connections in this loop.
+
+        //Traverse the linked list
+        pr = patch_list;
+        patch_list = pr->next;
+
+        int remember_this_connection = 0;
+
+        char * src_client_port;
+        char * dst_client_port;
+        asprintf( &src_client_port, "%s:%s", pr->src.client, pr->src.port );
+        asprintf( &dst_client_port, "%s:%s", pr->dst.client, pr->dst.port );
+
+        jack_port_t *jp_t_src;
+        jp_t_src = jack_port_by_name( client, src_client_port ); //client is our own jackpatch-jack-client.
+
+        if ( ! jp_t_src ) {
+            //The port does not exist anymore. We need to remember it!
+            //It doesn't matter if the destination port still exists, the file-writing below will only consider ports that are currently present and connected.
+            //printf("[jackpatch] We remember source %s but it does not exist anymore. Making sure it will not be forgotten.\n", src_client_port);
+            remember_this_connection = 1;
+        }
+        else {
+            //The source port does still exist, but is it's connection still alive?
+            //Do not use jack_port_get_all_connections, we want to know if a specific destination is still there.
+            jack_port_t *jp_t_dst;
+            jp_t_dst = jack_port_by_name( client, dst_client_port ); //client is our own jackpatch-jack-client.
+             if ( ! jp_t_dst ) {
+                //The port does not exist anymore. We need to remember it!
+                //It doesn't matter if the destination port still exists, the file-writing below will only consider ports that are currently present and connected.
+                //printf("[jackpatch] We remember destination %s but it does not exist anymore. Making sure it will not be forgotten.\n", dst_client_port);
+                remember_this_connection = 1;
+            }
+        }
+        if ( remember_this_connection ) {
+            //const char * pport = src_client_port;
+            //const char * pclient = dst_client_port;
+
+            //This code is replicated below #TODO: create function.
+            char *s;
+            asprintf( &s, "%-40s |> %s\n", src_client_port, dst_client_port ); //prepare the magic string that is the step before creating a struct from with process_patch //port is source client:port and connection is the destination one.
+            if ( table_index >= table_size )
+            {
+                table_size += table_increment;
+                table = (char**)realloc( table, table_size * sizeof( char *) );
+            }
+            table[table_index++] = s;
+            // process_patch( s ); infinite loop! But we still need to keep these patch_records! See below
+            // Verbose output that an individual connection was saved.
+            //printf( "[jackpatch] Remember ++ %s |> %s\n", src_client_port, dst_client_port );
+        }
+        free ( src_client_port );
+        free ( dst_client_port );
+    }
+
+    clear_all_patches(); //Tabula Rasa.
+
+    //We just removed the patch_records we wanted to remember.
+    //The last table_index holds the number of remembered records.
+    for ( int record=0; record < table_index; record++ )
+    {
+        process_patch ( table[record] );
+    }
+
     for ( port = ports; *port; port++ )
     {
+        //*port is a full client:port jack name, not only the port.
         jack_port_t *p;
 
         p = jack_port_by_name( client, *port );
@@ -489,19 +614,18 @@ snapshot ( const char *file )
 
         for ( connection = connections; *connection; connection++ )
         {
+            //This code is replicated above #TODO: create function.
             char *s;
-            asprintf( &s, "%-40s |> %s\n", *port, *connection );
-
+            asprintf( &s, "%-40s |> %s\n", *port, *connection ); //prepare the magic string that is the step before creating a struct from with process_patch //port is source client:port and connection is the destination one.
             if ( table_index >= table_size )
             {
                 table_size += table_increment;
                 table = (char**)realloc( table, table_size * sizeof( char *) );
             }
-
             table[table_index++] = s;
-
             process_patch( s );
-            printf( "[jackpatch]  ++ %s |> %s\n", *port, *connection );
+            // Verbose output that an individual connection was saved.
+            //printf( "[jackpatch]  ++ %s |> %s\n", *port, *connection );
         }
 
         free( connections );
@@ -521,6 +645,7 @@ snapshot ( const char *file )
     free(table);
 
     fclose( fp );
+
 }
 
 static int die_now = 0;
@@ -528,6 +653,7 @@ static int die_now = 0;
 void
 signal_handler ( int x )
 {
+    printf("[jackpatch] Handle signal %d\n", x);
     die_now = 1;
 }
 
@@ -536,7 +662,6 @@ die ( void )
 {
     if ( client_active )
         jack_deactivate( client );
-
     printf( "[jackpatch] Closing jack client\n" );
 
     jack_client_close( client );
@@ -585,7 +710,7 @@ osc_announce_reply ( const char *path, const char *types, lo_arg **argv, int arg
     if ( strcmp( "/nsm/server/announce", &argv[0]->s ) )
          return -1;
 
-    printf( "[jackpatch] Successfully registered. NSM says: %s", &argv[1]->s );
+    printf( "[jackpatch] Successfully registered. NSM says: %s\n", &argv[1]->s );
 
     nsm_is_active = 1;
     nsm_addr = lo_address_new_from_url( lo_address_get_url( lo_message_get_source( msg ) ) );
@@ -610,6 +735,7 @@ maybe_activate_jack_client ( void )
     {
         jack_activate( client );
         client_active = 1;
+        REAL_JACK_PORT_NAME_SIZE = jack_port_name_size(); //global. This is client+port+1. 64 + 256 + 1 = 321 on Linux.
     }
 }
 
@@ -627,7 +753,6 @@ osc_open ( const char *path, const char *types, lo_arg **argv, int argc, lo_mess
 
     if ( 0 == stat( new_filename, &st ) )
     {
-        printf( "[jackpatch]  Reading patch definitions from: %s\n", new_filename );
         if ( read_config( new_filename ) )
         {
             /* wipe_ports(); */
@@ -660,7 +785,7 @@ osc_open ( const char *path, const char *types, lo_arg **argv, int argc, lo_mess
 void
 announce ( const char *nsm_url, const char *client_name, const char *process_name )
 {
-    printf( "[jackpatch]  Announcing to NSM\n" );
+    printf( "[jackpatch] Announcing to NSM\n" );
 
     lo_address to = lo_address_new_from_url( nsm_url );
 
@@ -684,7 +809,7 @@ init_osc ( const char *osc_port )
 //error_handler );
 
     char *url = lo_server_get_url(losrv);
-    printf("[jackpatch]  OSC: %s\n",url);
+    printf("[jackpatch] OSC: %s\n",url);
     free(url);
 
     lo_server_add_method( losrv, "/nsm/client/save", "", osc_save, NULL );
@@ -746,7 +871,7 @@ port_registration_callback( jack_port_id_t id, int reg, void *arg )
 
     if ( size != jack_ringbuffer_write( port_ringbuffer, (const char *)pr, size ) )
     {
-        fprintf( stderr, "[jackpatch] ERROR: port notification buffer overrun" );
+        fprintf( stderr, "[jackpatch] ERROR: port notification buffer overrun\n" );
     }
 
 //    enqueue_new_port( port, reg );
@@ -763,6 +888,8 @@ main ( int argc, char **argv )
     static struct option long_options[] =
     {
         { "help", no_argument, 0, 'h' },
+        { "save", no_argument, 0, 's' },
+        { "version", no_argument, 0, 'v' },
         { 0, 0, 0, 0 }
     };
     int option_index = 0;
@@ -774,20 +901,37 @@ main ( int argc, char **argv )
             case 'h':
                 {
                 const char *usage =
-                "jackpatch - Remember the JACK Audio Connection Kit Graph in NSM\n\n"
-                "It is a module for the 'New Session Manager' and only communicates\n"
-                "over OSC in an NSM-Session and has no standalone functionality.\n"
+                "jackpatch - Remember and restore the JACK Audio Connection Kit Graph in NSM\n\n"
+                "It is intended as module for the 'New Session Manager' and only communicates\n"
+                "over OSC in an NSM-Session.\n\n"
+                "It has limited standalone functionality for testing and debugging, such as:\n"
                 "\n"
                 "Usage:\n"
+                "  jackpatch [filename]  Restore a snapshot from --save and monitor.\n"
                 "  jackpatch --help\n"
                 "\n"
                 "Options:\n"
-                "  --help                Show this screen\n"
+                "  --help                Show this screen and exit\n"
+                "  --version             Show version and exit\n"
+                "  --save                Save current connection snapshot to file and exit\n"
                 "";
                 puts ( usage );
                 exit(0);
                 break;
                 }
+
+           case 's':
+                {
+                    //save is handled below.
+                    break;
+                }
+
+           case 'v':
+                {
+                    printf("%s\n", VERSION);
+                    exit(0);
+                    break;
+                }
         }
     }
 
@@ -816,18 +960,35 @@ main ( int argc, char **argv )
         {
             if ( argc > 2 )
             {
-                printf( "[jackpatch] Saving current graph to: %s\n", argv[2] );
+
+                //To not discard temporarily missing clients we need to load the current ones from file first.
+                if ( read_config( argv[2] ) ) // --save parameter
+                {
+                    register_prexisting_ports();
+                }
+
+                printf( "[jackpatch] Standalone: Saving current graph to: %s\n", argv[2] );
                 snapshot( argv[2] );
                 die();
             }
         }
         else
         {
-            read_config( argv[1] );
-            printf( "[jackpatch] Monitoring...\n" );
+            /**
+             * Enter standalone commandline mode. This is without NSM.
+             */
+            if ( read_config( argv[1] ) )
+            {
+                maybe_activate_jack_client();
+                register_prexisting_ports();
+            }
+
+            printf( "[jackpatch] Monitoring in standalone mode…\n" );
             for ( ;; )
             {
                 usleep( 50000 );
+                if ( die_now )
+                    die();
                 check_for_new_ports();
             }
         }
